@@ -16,6 +16,11 @@
 Converts strings into unicode playing cards
 """
 
+import sys
+
+if sys.version_info.major == 3:
+    unichr = chr
+
 FACES = 'A23456789TJCQK', '123456789ABCDE'
 SUITS = 'SHDC', 'ABCD'
 RED, BLACK, RESET = '\x1b[31m', '\x1b[30m', '\x1b[39m'
@@ -25,10 +30,10 @@ def unicard(card, color=False):
     if card[:2] == '10':
         card = 'T' + card[2]
     face, suit = card.upper()
-    c = eval("u'\\U0001f0{}{}'".format(
+    c = unichr(int("0001f0{}{}".format(
         SUITS[1][SUITS[0].index(suit)],
         FACES[1][FACES[0].index(face)]
-    ))
+    ), base=16))
     if color:
         c = (suit in 'HD' and RED or BLACK) + c + RESET
     return c
